@@ -2,8 +2,8 @@ var NAVTREE =
 [
   [ "OpenMesh", "index.html", [
     [ "OpenMesh Documentation", "index.html", "index" ],
-    [ "Todo List", "a00731.html", null ],
-    [ "Deprecated List", "a00733.html", null ],
+    [ "Todo List", "a00745.html", null ],
+    [ "Deprecated List", "a00747.html", null ],
     [ "Modules", "modules.html", "modules" ],
     [ "Namespaces", null, [
       [ "Namespace List", "namespaces.html", "namespaces" ],
@@ -23,7 +23,7 @@ var NAVTREE =
         [ "All", "functions.html", "functions_dup" ],
         [ "Functions", "functions_func.html", "functions_func" ],
         [ "Variables", "functions_vars.html", null ],
-        [ "Typedefs", "functions_type.html", null ],
+        [ "Typedefs", "functions_type.html", "functions_type" ],
         [ "Enumerations", "functions_enum.html", null ],
         [ "Enumerator", "functions_eval.html", null ],
         [ "Related Functions", "functions_rela.html", null ]
@@ -42,23 +42,24 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 ".html",
-"a00082.html#a0f3fda415188e994a991b6fa3cfd1103",
-"a00084.html#aea28d40ad92eb9e30413c667fb2f97b7",
-"a00091.html#a7ead06ba4994b58587b3ecc293d0e120",
-"a00102.html#ab92e9e5aa0eef6d58957b8bb36e6420c",
-"a00129.html",
-"a00162.html",
-"a00186.html#a9341725d1628e2944726f07899fff94f",
-"a00191.html#a5b20965d17af71925e61e9b3b5f148d0",
-"a00215.html#a7bf4a80d6dbfa5a7fff510797e3ac112",
-"a00234.html#a102a60c0c7efc5e3ee9784b841e058ff",
-"a00237.html#a822dab13832e6151dc6c83e88d82625d",
-"a00247.html#a0ea0a6e1c470faaf15aa0aee55c08252",
-"a00263.html#a3ccf2b49df363bde2d0b9ee252360834",
-"a00287.html#aed8a2401d84d657de349759fd8c87352",
-"a00315.html",
-"a00559_source.html",
-"index.html#python_and_om"
+"a00080.html#a783378f6ae282850c4e8ddc3f259e629",
+"a00084.html#ada0982dd80f04ba36e027b71465cb1e6",
+"a00090.html#aaebf669727b60a21215ced7c90c24089",
+"a00098.html#aeaa3c6f90582538e7900bd42ddfd78b4",
+"a00127.html#a7b1f92033acee709fec3f8d3fb91cf7b",
+"a00155.html#a916aa4d94ce4674cb135e3fd396e2009",
+"a00188.html#af34eeffb0c72c285cbd647df31b376a1",
+"a00195.html#af68122190c9f3df2b6af4d670ee767e4",
+"a00219.html#aa5d267614ed43bc67586dde70ef763ad",
+"a00239.html#a9f4f797b08c045b611eaa6f8d149da21a1bc6e5b9faf304b2ad899896549cbd8c",
+"a00242.html#a7c30cac22e2368c8f08125f87319a100",
+"a00245.html#a9fc738c69147f4fa18cba94cd0d84523",
+"a00255.html#a417933da5ba5288fba4b7db06613b9ce",
+"a00271.html#a5f17747d0c277320b4f7465d504bcf2b",
+"a00297.html#a77daf35add9b86ce64f566dd9c46f2b7",
+"a00323.html#a2ff72386c44023020ee699c2bb36a76c",
+"a00572.html",
+"globals_defs.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
