@@ -1,41 +1,48 @@
-/*===========================================================================*\
+/* ========================================================================= *
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
- *                           www.openmesh.org                                *
+ *           Copyright (c) 2001-2015, RWTH-Aachen University                 *
+ *           Department of Computer Graphics and Multimedia                  *
+ *                          All rights reserved.                             *
+ *                            www.openmesh.org                               *
  *                                                                           *
- *---------------------------------------------------------------------------* 
- *  This file is part of OpenMesh.                                           *
+ *---------------------------------------------------------------------------*
+ * This file is part of OpenMesh.                                            *
+ *---------------------------------------------------------------------------*
  *                                                                           *
- *  OpenMesh is free software: you can redistribute it and/or modify         * 
- *  it under the terms of the GNU Lesser General Public License as           *
- *  published by the Free Software Foundation, either version 3 of           *
- *  the License, or (at your option) any later version with the              *
- *  following exceptions:                                                    *
+ * Redistribution and use in source and binary forms, with or without        *
+ * modification, are permitted provided that the following conditions        *
+ * are met:                                                                  *
  *                                                                           *
- *  If other files instantiate templates or use macros                       *
- *  or inline functions from this file, or you compile this file and         *
- *  link it with other files to produce an executable, this file does        *
- *  not by itself cause the resulting executable to be covered by the        *
- *  GNU Lesser General Public License. This exception does not however       *
- *  invalidate any other reasons why the executable file might be            *
- *  covered by the GNU Lesser General Public License.                        *
+ * 1. Redistributions of source code must retain the above copyright notice, *
+ *    this list of conditions and the following disclaimer.                  *
  *                                                                           *
- *  OpenMesh is distributed in the hope that it will be useful,              *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
- *  GNU Lesser General Public License for more details.                      *
+ * 2. Redistributions in binary form must reproduce the above copyright      *
+ *    notice, this list of conditions and the following disclaimer in the    *
+ *    documentation and/or other materials provided with the distribution.   *
  *                                                                           *
- *  You should have received a copy of the GNU LesserGeneral Public          *
- *  License along with OpenMesh.  If not,                                    *
- *  see <http://www.gnu.org/licenses/>.                                      *
+ * 3. Neither the name of the copyright holder nor the names of its          *
+ *    contributors may be used to endorse or promote products derived from   *
+ *    this software without specific prior written permission.               *
  *                                                                           *
-\*===========================================================================*/ 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED *
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A           *
+ * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER *
+ * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,  *
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,       *
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR        *
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF    *
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING      *
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS        *
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.              *
+ *                                                                           *
+ * ========================================================================= */
 
 /*===========================================================================*\
  *                                                                           *             
- *   $Revision: 990 $                                                         *
- *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05. Feb 2014) $                   *
+ *   $Revision$                                                         *
+ *   $Date$                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -176,17 +183,19 @@ PolyConnectivity::add_face(const VertexHandle* _vertex_handles, size_t _vhs_size
         do
           boundary_prev =
             opposite_halfedge_handle(next_halfedge_handle(boundary_prev));
-        while (!is_boundary(boundary_prev) || boundary_prev==inner_prev);
+        while (!is_boundary(boundary_prev));
         boundary_next = next_halfedge_handle(boundary_prev);
-        assert(is_boundary(boundary_prev));
-        assert(is_boundary(boundary_next));
+
         // ok ?
-        if (boundary_next == inner_next)
+        if (boundary_prev == inner_prev)
         {
           omerr() << "PolyMeshT::add_face: patch re-linking failed\n";
           return InvalidFaceHandle;
         }
 
+        assert(is_boundary(boundary_prev));
+        assert(is_boundary(boundary_next));
+
         // other halfedges' handles
         patch_start = next_halfedge_handle(inner_prev);
         patch_end   = prev_halfedge_handle(inner_next);
@@ -340,10 +349,10 @@ bool PolyConnectivity::is_collapse_ok(HalfedgeHandle v0v1)
     v1v0_triangle = valence(face_handle(v1v0)) == 3;
 
   //in a quadmesh we dont have the "next" or "previous" vhandle, so we need to look at previous and next on both sides
-  VertexHandle v_01_p = from_vertex_handle(prev_halfedge_handle(v0v1));
+  //VertexHandle v_01_p = from_vertex_handle(prev_halfedge_handle(v0v1));
   VertexHandle v_01_n = to_vertex_handle(next_halfedge_handle(v0v1));  
 
-  VertexHandle v_10_p = from_vertex_handle(prev_halfedge_handle(v1v0));
+  //VertexHandle v_10_p = from_vertex_handle(prev_halfedge_handle(v1v0));
   VertexHandle v_10_n = to_vertex_handle(next_halfedge_handle(v1v0));
 
   //are the vertices already deleted ?
@@ -358,12 +367,12 @@ bool PolyConnectivity::is_collapse_ok(HalfedgeHandle v0v1)
   {
     if (v0v1_triangle)
     {
-      VertexHandle vl = to_vertex_handle(next_halfedge_handle(v0v1));
+      //VertexHandle vl = to_vertex_handle(next_halfedge_handle(v0v1));
 
       HalfedgeHandle h1 = next_halfedge_handle(v0v1);
       HalfedgeHandle h2 = next_halfedge_handle(h1);
       if (is_boundary(opposite_halfedge_handle(h1)) && is_boundary(opposite_halfedge_handle(h2)))
-	return false;
+        return false;
     }
   }
 
@@ -373,12 +382,12 @@ bool PolyConnectivity::is_collapse_ok(HalfedgeHandle v0v1)
   {
     if (v1v0_triangle)
     {
-      VertexHandle vr = to_vertex_handle(next_halfedge_handle(v1v0));
+      //VertexHandle vr = to_vertex_handle(next_halfedge_handle(v1v0));
 
       HalfedgeHandle h1 = next_halfedge_handle(v1v0);
       HalfedgeHandle h2 = next_halfedge_handle(h1);
       if (is_boundary(opposite_halfedge_handle(h1)) && is_boundary(opposite_halfedge_handle(h2)))
-	return false;
+        return false;
     }
   }
 
@@ -825,7 +834,7 @@ bool PolyConnectivity::is_simple_link(EdgeHandle _eh) const
   HalfedgeHandle heh0 = halfedge_handle(_eh, 0);
   HalfedgeHandle heh1 = halfedge_handle(_eh, 1);
   
-  FaceHandle fh0 = face_handle(heh0);//fh0 or fh1 might be a invalid,
+  //FaceHandle fh0 = face_handle(heh0);//fh0 or fh1 might be a invalid,
   FaceHandle fh1 = face_handle(heh1);//i.e., representing the boundary
   
   HalfedgeHandle next_heh = next_halfedge_handle(heh0);
@@ -1145,9 +1154,9 @@ void PolyConnectivity::split_edge(EdgeHandle _eh, VertexHandle _vh)
   VertexHandle vfrom = from_vertex_handle(h0);
 
   HalfedgeHandle ph0 = prev_halfedge_handle(h0);
-  HalfedgeHandle ph1 = prev_halfedge_handle(h1);
+  //HalfedgeHandle ph1 = prev_halfedge_handle(h1);
   
-  HalfedgeHandle nh0 = next_halfedge_handle(h0);
+  //HalfedgeHandle nh0 = next_halfedge_handle(h0);
   HalfedgeHandle nh1 = next_halfedge_handle(h1);
   
   bool boundary0 = is_boundary(h0);
